@@ -5,7 +5,7 @@ from tqdm import tqdm
 from looptools import Counter
 
 
-class GenerateSQLite:
+class SQLiteSyntax:
     def __init__(self, table_name, data, header):
         self.table_name = table_name
         if type(data) == str:
@@ -105,7 +105,7 @@ class GenerateSQLite:
         return statements
 
 
-class ExecuteSQLite:
+class SQLiteQuery:
     def __init__(self, filepath):
         try:
             self.conn = sqlite3.connect(filepath)
@@ -177,7 +177,7 @@ class ExecuteSQLite:
             print('\tException: SQLite table ' + str(table_name) + ' is already empty, could not be truncated')
 
 
-class RunSQLite:
+class SQLiteTools:
     def __init__(self, db_filepath, table_name, data, header):
         self.db_filepath = db_filepath
         self.table_name = table_name
@@ -188,8 +188,8 @@ class RunSQLite:
     def update_table(self):
         db_filepath = str(self.db_filepath)
         # Generate SQL statements
-        create_tbl, insert_rows = GenerateSQLite(self.table_name, self.data, self.header).statement()
-        sql = ExecuteSQLite(db_filepath)  # Connect to SQLite database
+        create_tbl, insert_rows = SQLiteSyntax(self.table_name, self.data, self.header).statement()
+        sql = SQLiteQuery(db_filepath)  # Connect to SQLite database
 
         # Remove first item from data list
         self.data.pop(0)
